@@ -1,10 +1,10 @@
 """ Support 'markdown' filter. """
-
-from django import template
-from django.utils.safestring import mark_safe
-from django.utils.encoding import force_text
-
 import markdown as markdown_module
+from django import template
+from django.utils.encoding import force_text
+from django.utils.safestring import mark_safe
+
+from ..settings import MARKDOWN_EXTENSIONS
 
 
 register = template.Library()
@@ -17,8 +17,8 @@ def markdown(value):
     :returns: A rendered string
 
     """
-    return mark_safe(
-        markdown_module.markdown(force_text(value), safe_mode=False))
+    return mark_safe(markdown_module.markdown(
+        force_text(value), extensions=MARKDOWN_EXTENSIONS, safe_mode=False))
 
 
 @register.filter(is_safe=True)
@@ -28,5 +28,5 @@ def markdown_safe(value):
     :returns: A rendered string.
 
     """
-    return mark_safe(
-        markdown_module.markdown(force_text(value), safe_mode=True))
+    return mark_safe(markdown_module.markdown(
+        force_text(value), extensions=MARKDOWN_EXTENSIONS, safe_mode=True))
